#
# spec file for package guake
#
# Copyright (c) 2016 SUSE LINUX GmbH, Nuernberg, Germany.
# Copyright (c) 2011 Bjørn Lie
#
# All modifications and additions to the file contributed by third parties
# remain the property of their copyright owners, unless otherwise agreed
# upon. The license for this file, and modifications and additions to the
# file, is the same license as for the pristine package itself (unless the
# license for the pristine package is not an Open Source License, in which
# case the license is the MIT License). An "Open Source License" is a
# license that conforms to the Open Source Definition (Version 1.9)
# published by the Open Source Initiative.

# Please submit bugfixes or comments via http://bugs.opensuse.org/
#


Name:           guake
Version:        0.8.7
Release:        3.3
Summary:        A dropdown terminal for GNOME
License:        GPL-2.0+
Group:          System/X11/Terminals
Url:            http://guake-project.org/
Source:         https://github.com/Guake/guake/archive/%{version}.tar.gz
BuildRequires:  fdupes
BuildRequires:  gnome-common
BuildRequires:  intltool
BuildRequires:  python-devel
BuildRequires:  python-vte
BuildRequires:  update-desktop-files
BuildRequires:  pkgconfig(gconf-2.0)
BuildRequires:  pkgconfig(gtk+-2.0)
BuildRequires:  pkgconfig(pygtk-2.0)
Requires:       dbus-1-python
Requires:       libgnome
Requires:       python-gconf
Requires:       python-gtk
Requires:       python-keybinder
Requires:       python-notify
Requires:       python-vte
Requires:       python-xdg
Recommends:     %{name}-lang
BuildRoot:      %{_tmppath}/%{name}-%{version}-build
BuildArch:      noarch
%py_requires
%gconf_schemas_prereq

%description
Guake is a dropdown terminal made for the GNOME desktop environment.
Its style of window is based on an fps games, and one of its goals is
be easy to reach.

%lang_package
%prep
%setup -q

%build
# Drop shebangs from non-executable files
sed -i '1{/\/usr\/bin\/env/d;}' src/%{name}/{main,prefs}.py

# Run gnome-autogen.sh as upstream tarball is absolutely batshit-crazy...
NOCONFIGURE=1 gnome-autogen.sh
%configure --disable-schemas-install --disable-static
make %{?_smp_mflags}

%install
export GCONF_DISABLE_MAKEFILE_SCHEMA_INSTALL=1
%makeinstall DESTDIR=$RPM_BUILD_ROOT INSTALL="install -p"

%suse_update_desktop_file %{buildroot}%{_datadir}/applications/%{name}.desktop
%suse_update_desktop_file %{buildroot}%{_datadir}/applications/%{name}-prefs.desktop X-SuSE-ControlCenter-Personal

%find_gconf_schemas
%find_lang %{name} %{?no_lang_C}
%fdupes %{buildroot}%{python_sitelib}/%{name}/

%pre -f %{name}.schemas_pre

%preun -f %{name}.schemas_preun

%posttrans -f %{name}.schemas_posttrans

%post
%desktop_database_post
%icon_theme_cache_post

%postun
%desktop_database_postun
%icon_theme_cache_postun

%files -f %{name}.schemas_list
%defattr(-,root,root,-)
%doc AUTHORS ChangeLog COPYING NEWS
%{_bindir}/%{name}
%{_bindir}/%{name}-prefs
%{_datadir}/applications/%{name}.desktop
%{_datadir}/applications/%{name}-prefs.desktop
%{_datadir}/dbus-1/services/org.guake.Guake.service
%{_datadir}/%{name}/
%{_datadir}/icons/hicolor/*/*/*.*
%{_datadir}/pixmaps/%{name}/
%{_mandir}/man1/%{name}.1%{?ext_man}
%{python_sitelib}/%{name}/

%files lang -f %{name}.lang

%changelog
* Sat Sep 24 2016 badshah400@gmail.com
- Update to version 0.8.7:
  + Don't forget to update the version in about dialog box.
- Changes from previous versions:
  + See ChangeLog file (/usr/share/doc/packages/guake/NEWS) or
    release history at: https://github.com/Guake/guake/releases.
- Drop patch guake-fix-debug_mode-default.patch: incorporated
  upstream.
- Upstream now installs only to %%{python_sitelib}; drop the mv to
  %%{python_sitearch} and make package noarch.
- Use full URL for source tarball; update project URL to new home
  page.
- Run sed to remove unnecessary shebangs from non-executable
  files.
- Drop conditionals for old, unsupported openSUSE versions.
- Add Requires: python-keybinder; does not work without this.
* Wed Jun 10 2015 zaitor@opensuse.org
- Update to version 0.7.2:
  + Fix Ctrl+D regresion.
  + Update Quick Open Preference Window.
- Changes from version 0.7.1:
  + Background and font color inversed for some color schemes.
  + Guake width wrong on non-Unity Ubuntu desktop.
  + Add get_gtktab_name dbus interface.
  + Fix issue with selection copy.
  + I18n fixes.
  + Remove add and guake icon in tab.
  + prompt_on_close_tab option.
  + Fix default shortcuts for move tabs.
  + Updated translations.
- Changes from version 0.7.0:
  + Reorganised palette definition, add a demo terminal in
    preference panel.
  + Plenty of other new color palettes.
  + Don't propagate COLORTERM environment variable in terminal.
  + Force $TERM environment variable to 'xterm-256color' in
    terminals.
  + Fix issue with the quit confirmation dialog box.
  + Add shortcut for transparency level.
  + Add label to tell user how to disable a shortcut.
  + Expose cursor_shape and blink cursor method in pref window.
  + Expose Guake startup script to the pref window.
  + Some window management bug fixes.
  + Fix "Not focused on openning if tab was moved".
  + Add contextual menu item 'Open Link' on right click on a link.
  + Fix compatibility with Ubuntu 15.04.
  + Fix Guake Turns Gray sometimes.
- Drop guake-default-transparency.patch: Fixed slightly different
  upstream.
- Add guake-fix-debug_mode-default.patch: Fix default value of
  debug_mode in schema.
- Pass --disable-schemas-install to configure and further tweak
  schema installs.
* Thu Dec 18 2014 zaitor@opensuse.org
- Update to version 0.5.2:
  + Bug fixes.
  + Disable the 'focus_if_open' feature (hidden trigger, true per
    default). Restaure focus does not work in all systems.
  + Lot of "componentization" of the code, in preparation to the
    rebase of 'gtk3' branch.
- Changes from version 0.5.1:
  + Minor bug fixes.
- "Disable" source-url, as I can't get osc to download from it
  correctly.
* Fri Oct 10 2014 zaitor@opensuse.org
- Add libgnome Requires: guake segfaults without it.
* Sat Sep 27 2014 zaitor@opensuse.org
- Update to version 0.5.0:
  + Tab can be moved.
  + Add change tab hotkey (F1-F10 by default).
  + Add "New tab" menu item.
  + Quick open file path within the terminal output gconf only
    settings:
  - startup scripts
  - vertical aligments.
  + Updated translations.
- Stop rm'ing Norwegian translation, as it's now fixed upstream.
- Add gnome-common BuildRequires and run gnome-autogen.sh as
  upstream tarball is not properly bootstrapt.
- Drop conditional vte Requires  and run of post/postun for
  obsolete releases.
- Update Url and Source links to new home on github.
* Tue Jan 22 2013 rbrownccb@opensuse.org
- Add guake-default-transparency.patch to set default
  transparency lower. (bnc#799862).
* Fri Dec  7 2012 douglarek@outlook.com
- Add runtime dependency: python-xdg
* Fri Jul 27 2012 zaitor@opensuse.org
- Update to version 0.4.4:
  + New icon for both guake and guake-prefs.
  + Improved build scripts for themable icon installation.
  + Updated some autotools files.
  + Fixing a typo in the guake-prefs.desktop file. (bnc#763244).
  + wm_class can't be get by gnome-shell css.
  + Add the missing "System" category required by FDO menu
    specification.
  + Do not install the system-wide autostart file.
  + Call window.move/resize only when not in fullscreen mode.
  + Terminal scrolls to the wrong position when hiding and unhiding
    in fullscreen mode.
  + Toggle fullscreen malfunction.
  + Guake overlaped the second screen in a dual-monitor setup with
    a sidepanel.
  + Tree items in Keyboard shortcuts tab of preferences window not
    localized.
  + Add option to start in fullscreen mode.
  + Refactoring of the fullscreen logic and addition of the
  - -fullscreen flag.
- Drop guake-fix-pref.desktop.patch, fixed upstream.
- Add %%icon_theme_cache_* macros to post and postun and for the new
  scalable icons.
- Drop %%suse_update_desktop_file call for systemwide autostart
  file: not installed anymore.
- Add proper sourceurl for Source0.
* Mon Jun 11 2012 dimstar@opensuse.org
- Update to version 0.4.3:
  + Better tab titling, based on VTE title sequences
  + Some drag & drop support
  + Fix for the many times reported "gconf proxy port as int" issue
  + Better file layout which doesn't modify PYTHONPATH
  + Updated translations.
- Drop guake-glib-2.31.patch: fixed upstream.
* Mon May 21 2012 zaitor@opensuse.org
- Add guake-fix-pref.desktop.patch, spelling mistake in desktop
  file (bnc#763244).
- Use full URL for Source0.
* Sat Mar  3 2012 zaitor@opensuse.org
- Fix build on SLE11, with some SLE11 specific changes:
  + Use vte-devel BuildRequires instead of python-vte.
  + Use vte Requires instead of python-vte.
- Do not explicitly list schema files in %%files; use the
  schemas_list file that was generated instead.
* Sat Jan 21 2012 zaitor@opensuse.org
- Added upstream url for guake-glib-2.31.patch bug.
* Tue Nov 29 2011 zaitor@opensuse.org
- Add guake-glib-2.31.patch: Fix build with glib 2.31.
* Tue Oct 11 2011 vuntz@opensuse.org
- Cleanup for inclusion in Factory.
* Mon Oct  3 2011 zaitor@opensuse.org
  + Changed into pkgconfig BuildRequires
  - Clean up spec.
  + Added Requires on python-gconf.
* Thu Apr 28 2011 zaitor@opensuse.org
- Copy from packman.
* Sun Sep 12 2010 detlef@links2linux.de
- initial build for PackMan <0.4.2>
